@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for resource-groups service client
 
@@ -10,10 +11,12 @@ Usage::
     client: ResourceGroupsClient = boto3.client("resource-groups")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
+from typing import Any, Dict, List, Type, overload
+
 from botocore.exceptions import ClientError as Boto3ClientError
+from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_resource_groups.paginator import (
     ListGroupResourcesPaginator,
     ListGroupsPaginator,
@@ -182,3 +185,6 @@ class ResourceGroupsClient:
         """
         [Paginator.SearchResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/resource-groups.html#ResourceGroups.Paginator.SearchResources)
         """
+
+    def get_paginator(self, operation_name: str) -> Boto3Paginator:
+        pass
