@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for resource-groups service client paginators.
 
@@ -20,9 +21,10 @@ Usage::
     search_resources_paginator: SearchResourcesPaginator = client.get_paginator("search_resources")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Iterator, List, TYPE_CHECKING
+from typing import Iterator, List
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_resource_groups.type_defs import (
     GroupFilterTypeDef,
     ListGroupResourcesOutputTypeDef,
@@ -33,7 +35,6 @@ from mypy_boto3_resource_groups.type_defs import (
     SearchResourcesOutputTypeDef,
 )
 
-
 __all__ = ("ListGroupResourcesPaginator", "ListGroupsPaginator", "SearchResourcesPaginator")
 
 
